@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-17 11:19:05
-@LastEditTime: 2021-09-02 11:10:38
+@LastEditTime: 2021-09-03 10:43:17
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -722,3 +722,72 @@ class JoinMemberHandler(TaoBaseHandler):
         :last_editors: HuangJianYi
         """
         return invoke_result_data
+
+
+class BrowseSiteHandler(TaoBaseHandler):
+    """
+    :description: 处理浏览网址相关任务 如：浏览店铺、浏览直播间、浏览会场/专题
+    """
+    @filter_check_params("act_id,tb_user_id,login_token")
+    def get_async(self):
+        """
+        :description: 处理浏览商品任务
+        :param app_id:应用标识
+        :param act_id:活动标识
+        :param module_id:活动模块标识
+        :param tb_user_id:用户标识
+        :param task_type:任务类型
+        :param task_sub_type:子任务类型
+        :param login_token:访问令牌
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        app_id = self.get_taobao_param().source_app_id
+        act_id = int(self.get_param("act_id", 0))
+        user_id = int(self.get_param("tb_user_id", 0))
+        module_id = int(self.get_param("module_id", 0))
+        task_type = int(self.get_param("task_type", 0))
+        task_sub_type = self.get_param("task_sub_type")
+        login_token = self.get_param("login_token")
+        task_base_model = TaskBaseModel(context=self)
+
+        invoke_result_data = InvokeResultData()
+        if task_type not in [TaskType.browse_store.value,TaskType.browse_live_room.value,TaskType.browse_special_topic.value]:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message = "非法操作"
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        invoke_result_data = self.business_process_executing(app_id, act_id, user_id, module_id, login_token)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        invoke_result_data = task_base_model.process_browse_site(app_id, act_id, module_id, user_id, login_token, task_type, task_sub_type, self.__class__.__name__, invoke_result_data.data["check_user_nick"], invoke_result_data.data["continue_request_expire"])
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        invoke_result_data = self.business_process_executed(invoke_result_data)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        return self.response_json_success(invoke_result_data.data)
+
+    def business_process_executing(self, app_id, act_id, user_id, module_id, login_token):
+        """
+        :description: 执行前事件
+        :param app_id:应用标识
+        :param act_id:活动标识
+        :param module_id:活动模块标识
+        :param user_id:用户标识
+        :param login_token:访问令牌
+        :return:
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        invoke_result_data.data = {"check_user_nick": True, "continue_request_expire": 5}
+        return invoke_result_data
+
+    def business_process_executed(self, invoke_result_data):
+        """
+        :description: 执行后事件
+        :param invoke_result_data:框架处理结果
+        :return:
+        :last_editors: HuangJianYi
+        """
+        return invoke_result_data
