@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 18:31:06
-@LastEditTime: 2021-09-02 09:28:55
+@LastEditTime: 2021-09-03 19:50:31
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -289,7 +289,7 @@ class GetJoinMemberUrlHandler(TaoBaseHandler):
             return self.response_json_error("error", "小程序不存在")
         app_key, app_secret = self.get_app_key_secret()
         user_base_model = UserBaseModel(context=self)
-        invoke_result_data = self.response_json_success(user_base_model.get_join_member_url(app_info_dict["access_token"], app_key, app_secret, is_log=is_log))
+        invoke_result_data = user_base_model.get_join_member_url(app_info_dict["access_token"], app_key, app_secret, is_log=is_log)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
