@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-12 20:11:48
-@LastEditTime: 2021-08-31 16:28:44
+@LastEditTime: 2021-09-03 15:43:31
 @LastEditors: HuangJianYi
 :description: 
 """
@@ -53,6 +53,52 @@ class FrameBaseHandler(BaseApiHandler):
         """
         return SevenHelper.json_loads(rep_str)
 
+    def base64_encode(self, source, encoding="utf-8"):
+        """
+        :Description: base64加密
+        :param source: 需加密的字符串
+        :return: 加密后的字符串
+        :last_editors: HuangJianYi
+        """
+        if not source.strip():
+            return ""
+        import base64
+        encode_string = str(base64.b64encode(source.encode(encoding=encoding)), 'utf-8')
+        return encode_string
+
+    def base64_decode(self, source):
+        """
+        :Description: base64解密
+        :param source: 需加密的字符串
+        :return: 解密后的字符串
+        :last_editors: HuangJianYi
+        """
+        if not source.strip():
+            return ""
+        import base64
+        decode_string = str(base64.b64decode(source), 'utf-8')
+        return decode_string
+
+    def get_request_param(self, param_name, default="", strip=True):
+        """
+        :description: 二次封装获取参数
+        :param param_name: 参数名
+        :param default: 如果无此参数，则返回默认值
+        :param filter_sql: 是否过滤sql关键字
+        :return: 参数值
+        :last_editors: HuangJianYi
+        """
+        param_ret = ""
+        if self.request.method == "POST" and self.request.body:
+            if not self.param_info:
+                self.param_info = json.loads(self.request.body)
+            param_ret = self.param_info[param_name] if self.param_info.__contains__(param_name) else ""
+        else:
+            param_ret = self.get_argument(param_name, default, strip=strip)
+        if param_ret == "" or param_ret == "undefined":
+            param_ret = default
+        return param_ret
+
     def response_custom(self, rep_dic):
         """
         :description: 输出公共json模型
@@ -188,12 +234,12 @@ class FrameBaseHandler(BaseApiHandler):
                 result = True, f"操作太频繁,请{expire}毫秒后再试"
         return result
 
-    def get_signature_md5(self,request_param_dict,sign_key=""):
+    def get_signature_md5(self,request_param_dict,encrypt_key=""):
         """
         :description: 参数按照加密规则进行MD5加密
-        :description: 签名规则 signature_md5= ((参数1=参数1值&参数2=参数2值&signature_stamp={signature_stamp}))+密钥)进行Md5加密，参数顺序按照字母表的顺序排列
+        :description: 签名规则 SignatureMD5= ((参数1=参数1值&参数2=参数2值&SignatureStamp={SignatureStamp}))+密钥)进行Md5加密转小写，参数顺序按照字母表的顺序排列
         :param request_param_dict: 请求参数字典
-        :param sign_key: 接口密钥
+        :param encrypt_key: 接口密钥
         :return: 加密后的md5值，由于跟客户端传来的加密参数进行校验
         """
         request_sign_params = {}
@@ -208,7 +254,7 @@ class FrameBaseHandler(BaseApiHandler):
         request_message = request_message.replace("_seven_", "%20").replace("_seven1_", "(").replace("_seven2_", ")").replace("%27", "'")
         # MD5摘要
         request_encrypt = hashlib.md5()
-        request_encrypt.update((request_message + str(sign_key)).encode("utf-8"))
+        request_encrypt.update((request_message + str(encrypt_key)).encode("utf-8"))
         check_request_signature_md5 = request_encrypt.hexdigest().lower()
         return check_request_signature_md5
 
@@ -476,7 +522,7 @@ class WeChatBaseHandler(FrameBaseHandler):
             # 将设备信息字符串转为字典类型
             clientheaderinfo_string = self.request.headers._dict.get("Clientheaderinfo")
             if clientheaderinfo_string:
-                self.device_info_dict = self.get_device_info(clientheaderinfo_string)
+                self.device_info_dict = self.device_info_dict(clientheaderinfo_string)
 
             user_id = self.get_param("user_id")
             if user_id:
@@ -489,7 +535,7 @@ class WeChatBaseHandler(FrameBaseHandler):
             self.logging_link_error("【微信handler基类】"+ str(ex))
 
 
-    def get_device_info(self, device_str):
+    def device_info_dict(self, device_str):
         """
         :description: 获取头部参数字典
         :param device_string:头部信息串
@@ -497,33 +543,31 @@ class WeChatBaseHandler(FrameBaseHandler):
         """
         device_info_dict = {}
         info_model = parse_qs(device_str)
-        device_info_dict["pid"] = int(info_model["PID"][0])
-        device_info_dict["union_id"] = "" if "UnionID" not in info_model.keys() else info_model["UnionID"][0]
-        device_info_dict["height"] = 0 if "Height" not in info_model.keys() else int(info_model["Height"][0])
-        device_info_dict["width"] = 0 if "Width" not in info_model.keys() else int(info_model["Width"][0])
-        device_info_dict["version"] = "" if "Version" not in info_model.keys() else info_model["Version"][0]  # 客户端版本号
-        device_info_dict["app_version"] = "" if "AppVersion" not in info_model.keys() else info_model["AppVersion"][0]  # 小程序版本号
-        device_info_dict["net"] = "" if "Net" not in info_model.keys() else info_model["Net"][0]
-        device_info_dict["model_p"] = "" if "Model" not in info_model.keys() else info_model["Model"][0]
-        device_info_dict["lang"] = "" if "Lang" not in info_model.keys() else info_model["Lang"][0]
-        device_info_dict["ver_no"] = "" if "VerNo" not in info_model.keys() else info_model["VerNo"][0]  #接口版本号
-        device_info_dict["chid"] = 0 if "CHID" not in info_model.keys() else int(info_model["CHID"][0])
-        device_info_dict["signature_stamp"] = 0 if "SignatureStamp" not in info_model.keys() else int(info_model["SignatureStamp"][0])
-        device_info_dict["signature_md5"] = "" if "SignatureMD5" not in info_model.keys() else info_model["SignatureMD5"][0]
+        device_info_dict["pid"] = int(info_model["pid"][0])  # 产品标识
+        device_info_dict["height"] = 0 if "height" not in info_model.keys() else int(info_model["height"][0]) # 高度
+        device_info_dict["width"] = 0 if "width" not in info_model.keys() else int(info_model["width"][0]) # 宽度
+        device_info_dict["version"] = "" if "version" not in info_model.keys() else info_model["version"][0]  # 客户端版本号
+        device_info_dict["app_version"] = "" if "app_version" not in info_model.keys() else info_model["app_version"][0]  # 小程序版本号
+        device_info_dict["net"] = "" if "net" not in info_model.keys() else info_model["net"][0]   # 网络
+        device_info_dict["model_p"] = "" if "model" not in info_model.keys() else info_model["model"][0]  # 机型
+        device_info_dict["lang"] = "" if "lang" not in info_model.keys() else info_model["lang"][0]  #语言
+        device_info_dict["ver_no"] = "" if "ver_no" not in info_model.keys() else info_model["ver_no"][0]  #接口版本号
+        device_info_dict["chid"] = 0 if "chid" not in info_model.keys() else int(info_model["chid"][0]) # 渠道标识
+        device_info_dict["signature_stamp"] = 0 if "signature_stamp" not in info_model.keys() else int(info_model["signature_stamp"][0]) # 时间搓秒
+        device_info_dict["signature_md5"] = "" if "signature_md5" not in info_model.keys() else info_model["signature_md5"][0]  # 签名md5
         return device_info_dict
 
 
-def filter_check_head(is_check=True, no_check_params=None, sign_key=""):
+def filter_check_head_sign(is_check=True, no_check_params=None):
     """
     :description: 头部过滤装饰器 仅限handler使用
     :param is_check: 是否开启校验
     :param no_check_params: 不加入参数校验的参数集合
-    :param sign_key: 签名key
     :last_editors: HuangJianYi
     """
     def check_head(handler):
         def wrapper(self, **args):
-
+            encrypt_key = config.get_value("encrypt_key", "3924e337a476475e95b2b341eaba8c1c")
             is_check_head = config.get_value("is_check_head", True)
             if is_check_head == False:
                 is_check = False
@@ -539,21 +583,20 @@ def filter_check_head(is_check=True, no_check_params=None, sign_key=""):
                         no_check_array = []
                     # 验证是否有设备信息
                     clientheaderinfo_string = self.request.headers._dict.get("Clientheaderinfo")
-                    # clientheaderinfo_string = "CHID=1&Height=520&Lang=zh_CN&Model=iPhone%205&Net=unknown&PID=1&PixelRatio=2&SignatureStamp=1611321295380&Ver=1&Version=7.0.4&Width=320"
                     if clientheaderinfo_string:
                         # 将设备信息字符串转为字典类型
-                        device_dict = self.get_device_info(clientheaderinfo_string)
+                        device_info_dict = self.device_info_dict(clientheaderinfo_string)
                         # 验证签名超时 10分钟过期
                         now_time = TimeHelper.get_now_timestamp(True)
-                        if now_time - device_dict["signature_stamp"] > int(1000 * 60 * 10):
-                            return self.response_json_error("signature_stamp", "登录超时")
+                        if now_time - device_info_dict["signature_stamp"] > int(1000 * 60 * 10):
+                            return self.response_json_error("signature_stamp", "超时操作")
                         # 验证是否有头部信息签名
-                        if not device_dict.__contains__("signature_md5"):
+                        if not device_info_dict.__contains__("signature_md5"):
                             return self.response_json_error("signature_md5", "缺少参数signature_md5")
                         # 验证头部签名是否成功
-                        client_head_dict = dict([(k, v[0]) for k, v in parse_qs(clientheaderinfo_string, True).items() if k != "signature_md5" and not k in no_check_array])
-                        head_signature_md5 = self.get_signature_md5(client_head_dict, sign_key)
-                        signature_md5 = device_dict["signature_md5"].lower()
+                        client_head_dict = dict([(k, v[0]) for k, v in parse_qs(clientheaderinfo_string, True).items() if not k in no_check_array])
+                        head_signature_md5 = self.get_signature_md5(client_head_dict, encrypt_key)
+                        signature_md5 = device_info_dict["signature_md5"].lower()
                         if signature_md5 != head_signature_md5:
                             return self.response_json_error("signature_fail", "头部签名验证失败")
                     else:
@@ -566,4 +609,51 @@ def filter_check_head(is_check=True, no_check_params=None, sign_key=""):
 
         return wrapper
 
-    return check_head
\ No newline at end of file
+    return check_head
+
+
+def filter_check_params_sign(is_check=True, no_check_params=None):
+    """
+    :description: 请求参数过滤装饰器 仅限handler使用
+    :param is_check: 是否开启校验
+    :param no_check_params: 不加入参数校验的参数集合
+    :last_editors: HuangJianYi
+    """
+    def check_params(handler):
+        def wrapper(self, **args):
+            encrypt_key = config.get_value("encrypt_key", "3924e337a476475e95b2b341eaba8c1c")
+            is_check_params = config.get_value("is_check_params", True)
+            if is_check_params == False:
+                is_check = False
+            else:
+                is_check = True
+            if is_check == True:
+                try:
+                    if type(no_check_params) == str:
+                        no_check_array = no_check_params.split(",")
+                    elif type(no_check_params) == list:
+                        no_check_array = no_check_params
+                    else:
+                        no_check_array = []
+                    # 验证参数
+                    request_param_dict = {}
+                    if self.request.method != "GET" and self.request.body:
+                        request_param_dict = json.loads(self.request.body)
+                    else:
+                        request_param_dict = dict([(k, v[0]) for k, v in parse_qs(self.request.query, True).items() if not k in no_check_array])
+                    if not request_param_dict.__contains__("param_signature_md5"):
+                        return self.client_reponse_json_error("signature_fail", "缺少参数param_signature_md5")
+                    check_request_signature_md5 = self.get_signature_md5(request_param_dict, encrypt_key)
+                    param_signature_md5 = request_param_dict["param_signature_md5"].lower()
+                    if check_request_signature_md5 != param_signature_md5:
+                        return self.client_reponse_json_error("signature_fail", "参数签名验证失败")
+
+                except Exception as ex:
+                    self.logging_link_error("【请求参数校验异常】" + str(ex))
+                    return self.response_json_error("error", "请求参数验证失败")
+
+            return handler(self, **args)
+
+        return wrapper
+
+    return check_params
\ No newline at end of file
