@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2021-08-18 18:10:06
+@LastEditTime: 2021-09-06 17:31:59
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -105,12 +105,12 @@ class UpdateActInfoHandler(TaoBaseHandler):
         """
         app_id = self.get_app_id()
         act_id = int(self.get_param("act_id", 0))
-        act_name = self.get_param("act_name", "")
+        act_name = self.get_param("act_name", None)
         theme_id = int(self.get_param("theme_id", -1))
         is_share = int(self.get_param("is_share", -1))
-        share_desc_json = self.get_param("share_desc_json", "-1")
+        share_desc_json = self.get_param("share_desc_json", None)
         is_rule = int(self.get_param("is_rule", -1))
-        rule_desc_json = self.get_param("rule_desc_json", "-1")
+        rule_desc_json = self.get_param("rule_desc_json", None)
         is_release = int(self.get_param("is_release", -1))
         start_date = self.get_param("start_date", None)
         end_date = self.get_param("end_date", None)
