@@ -2,16 +2,16 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-15 11:30:45
-@LastEditTime: 2021-08-02 08:54:18
+@LastEditTime: 2021-08-25 09:32:03
 @LastEditors: HuangJianYi
 @Description: 
 """
 # -*- coding: utf-8 -*-
 """
-:Author: HuangJingCan
+:Author: HuangJianYi
 :Date: 2020-05-26 11:34:07
 :LastEditTime: 2020-12-07 16:26:12
-:LastEditors: HuangJingCan
+:LastEditors: HuangJianYi
 :description: 阿里云存储
 """
 import oss2
@@ -23,10 +23,10 @@ from seven_framework import ExcelHelper, config
 
 class OSS2Helper:
     """
-    :description: 阿里云存储帮助类
+    :description: 阿里云存储帮助类 上传文件、数据导入excel并返回下载地址
     :param {type} 
     :return: 
-    :last_editors: HuangJingCan
+    :last_editors: HuangJianYi
     """
     AK_ID = "LTAI4GAV8q6wxi2gqispR4my"
     AK_SECRET = "LWBuIALo4X4pnBDCwiuRjZur1Yhm5h"
@@ -43,7 +43,7 @@ class OSS2Helper:
         :param is_auto_name：是否生成随机文件名
         :param data：需要上传的数据
         :return: 
-        :last_editors: HuangJingCan
+        :last_editors: HuangJianYi
         """
         # 文件名
         file_name = os.path.basename(local_file) if local_file != "" else file_name
