@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-28 09:54:51
-@LastEditTime: 2021-08-26 10:28:33
+@LastEditTime: 2021-09-06 17:33:46
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -195,7 +195,7 @@ class ActBaseModel():
             return invoke_result_data
         old_act_info = deepcopy(act_info)
         now_datetime = SevenHelper.get_now_datetime()
-        if act_name:
+        if act_name !=None:
             act_info.act_name = act_name
         if is_release !=-1:
             act_info.is_release = is_release
@@ -203,12 +203,12 @@ class ActBaseModel():
             act_info.theme_id = theme_id
         if is_share !=-1:
             act_info.is_share = is_share
-        if share_desc_json:
-            act_info.share_desc_json = share_desc_json if share_desc_json else {}
+        if share_desc_json !=None:
+            act_info.share_desc_json = share_desc_json
         if is_rule !=-1:
             act_info.is_rule = is_rule
-        if rule_desc_json:
-            act_info.rule_desc_json = rule_desc_json if rule_desc_json else []
+        if rule_desc_json !=None:
+            act_info.rule_desc_json = rule_desc_json
         if is_release !=-1:
             act_info.is_release = is_release
             act_info.release_date = now_datetime
