@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-27 10:55:09
-@LastEditTime: 2021-08-25 10:06:04
+@LastEditTime: 2021-09-02 17:10:37
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -26,7 +26,7 @@ class PrizeRoster:
 
     def __init__(self):
         super(PrizeRoster, self).__init__()
-        self.id = 0  # id(act_id+user_id+guid)md5int生成
+        self.id = 0  # id
         self.app_id = ""  # 应用标识
         self.act_id = 0  # 活动标识
         self.user_id = 0  # 用户标识
