@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-04 13:41:15
-@LastEditTime: 2021-08-19 15:23:13
+@LastEditTime: 2021-08-26 10:29:53
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -15,7 +15,7 @@ from seven_cloudapp_frame.models.db_models.user.user_info_model import *
 
 class PrizeBaseModel():
     """
-    :description: 奖品基类
+    :description: 活动奖品业务模型
     """
     def __init__(self, context):
         self.context = context
