@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-08-12 09:06:24
-@LastEditTime: 2021-09-03 11:15:34
+@LastEditTime: 2021-09-06 15:29:58
 @LastEditors: HuangJianYi
 :description: 淘宝top接口基础类
 """
@@ -986,6 +986,8 @@ class TopBaseModel():
                 if "result" in resp["crm_member_joinurl_get_response"].keys():
                     if "result" in resp["crm_member_joinurl_get_response"]["result"].keys():
                         invoke_result_data.data = resp["crm_member_joinurl_get_response"]["result"]["result"]
+                        if invoke_result_data.data and "https:" not in invoke_result_data.data and "http:" not in invoke_result_data.data:
+                            invoke_result_data.data = "https:" + invoke_result_data.data
                         return invoke_result_data
         except Exception as ex:
             self.context.logging_link_error(traceback.format_exc())
