@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 11:10:20
-@LastEditTime: 2021-09-06 15:17:39
+@LastEditTime: 2021-09-06 11:31:24
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -156,10 +156,7 @@ class UserBaseModel(FrameBaseModel):
         :last_editors: HuangJianYi
         """
         top_base_model = TopBaseModel(context=self.context)
-        join_member_url = top_base_model.get_join_member_url(access_token,app_key,app_secret,is_log)
-        if join_member_url and "https:" not in join_member_url and "http:" not in join_member_url:
-            join_member_url = "https:" + join_member_url
-        return join_member_url
+        return top_base_model.get_join_member_url(access_token,app_key,app_secret,is_log)
     
     def save_user_by_openid(self, app_id, act_id, open_id, user_nick, avatar, union_id=""):
         """
